@@ -686,7 +686,12 @@ Want to download more cities?</source>
         <translation>Настройки</translation>
     </message>
     <message>
-        <location line="+68"/>
+        <location line="+637"/>
+        <source>Swipe for change routes</source>
+        <translation>Свайп для изменения маршрута</translation>
+    </message>
+    <message>
+        <location line="-569"/>
         <source>Interface</source>
         <translation>Интерфейс</translation>
     </message>
