@@ -1,11 +1,17 @@
 //#include <QDebug>
+#include <qglobal.h>
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#else
+#include <QtGui>
+#endif
 
 #include "completer.h"
 #include "mapview/mapview.h"
 //#include "flickcharm.h"
 
 TCompleter::TCompleter(TMapView *mapView,QLineEdit *parent)
- : QObject(parent), editor(parent)
+ : editor(parent)
 {
  map=mapView;
  list=map->getNamesAndColors();
@@ -15,8 +21,8 @@ TCompleter::TCompleter(TMapView *mapView,QLineEdit *parent)
  indColor=1;
  if(MobileVersion) qSwap(indName,indColor);
 
- popup = new QTreeWidget(parent);
- popup->setStyleSheet("show-decoration-selected:1;");
+ popup = new QTreeWidget((QWidget*)parent);
+ popup->setStyleSheet("QTreeWidget{show-decoration-selected:1;}"+qApp->styleSheet());
  popup->setWindowFlags(Qt::Popup);
  popup->setFocusPolicy(Qt::NoFocus);
  popup->setMouseTracking(true);
