@@ -1,4 +1,5 @@
 #include <QDebug>
+#include <qglobal.h>
 #include <QTextCodec>
 
 #include "main.h"
@@ -23,8 +24,11 @@ int main(int argc, char *argv[])
  QCoreApplication::setAttribute(Qt::AA_S60DisablePartialScreenInputMode, false);
 #endif
 
- QTextCodec *codec = QTextCodec::codecForName("cp1251");
- QTextCodec::setCodecForTr(codec);
+#if QT_VERSION < 0x050000
+ QTextCodec *codec = QTextCodec::codecForName("utf-8");
+// QTextCodec::setCodecForLocale(codec);
+ QTextCodec::setCodecForCStrings(codec);
+#endif
 
  //tTimer.start();
  MainWindow w;
