@@ -25,6 +25,8 @@
 #include "mobileui.h"
 #include "flickcharm.h"
 
+#include "swipegesturerecognizer.h"
+
 //#ifdef MEEGO_EDITION_HARMATTAN
 //#include <QX11Info>
 //#include <X11/Xatom.h>
@@ -33,7 +35,7 @@
 
 
 #ifdef Q_OS_SYMBIAN
-QString VERSION="0.6.5";
+QString VERSION="0.6.7";
 #endif
 
 QString URL_MAPS="http://pmetro.su/Maps.html";
@@ -46,12 +48,12 @@ QString STYLE_MAP_DEFAULT=
   "QToolButton{border-image:url(:/img/button_inactive.png);height:%1px;width:%1px;background:transparent;padding:0.2em;margin-top:%6px;margin-left:%6px;} "
   "QToolButton:pressed{border-image:url(:/img/button_active.png);margin-top:%5px;margin-left:%5px;} "
 //  "QLabel{padding-left:%7px;padding-right:%7px;margin-left:%5px;} "
-  "QLineEdit{padding-left:%6px;}",
+  "QLineEdit{padding-left:%6px;}/*%1%2%3%4%5%6%7*/",
   STYLE_MAP=STYLE_MAP_DEFAULT;
 
 QString STYLE_MAIN_DEFAULT=
   "QToolBox::tab{padding-left:1em;text-transform:uppercase;background:palette(button);border-bottom:0.2em solid palette(highlight);border-bottom-left-radius:0.5em;border-bottom-right-radius:0.5em;}"
-  "QToolBox::tab:selected{font:bold;border-bottom:0.3em solid palette(highlight);}",
+  "QToolBox::tab:selected{font:bold;border-bottom:0.3em solid palette(highlight);}/*%1%2%3%4%5%6%7*/",
 STYLE_MAIN=STYLE_MAIN_DEFAULT, SKIN_DEFAULT, STYLE_FONT_DEFAULT;
 
 MainWindow *mainWnd;
@@ -83,15 +85,15 @@ QMainWindow(parent),map(NULL),SettingsWindow(NULL),ui(new Ui::MainWindow),mUi(NU
  //MobileVersion=1;
  //setAttribute(Qt::WA_AutoOrientation);
  setAttribute(Qt::WA_AcceptTouchEvents);
- codePage = QTextCodec::codecForName("windows-1251");
- SKIN_DEFAULT=this->style()->objectName();
+ codePage = QTextCodec::codecForName("Windows-1251");
+ SKIN_DEFAULT=Config.appSkinName=this->style()->objectName().toLower();
  STYLE_FONT_DEFAULT=qApp->font().toString();
  mainWnd=this;
  IniGroupStr << "MapView"<<"Main"<<"Other";
  IniKeyStr << "Skin"<<"StationCustomFont"<<"StationFont"<<"StationBack"<<"StationShadow"<<"StationBackColor"<<"StationShadowColor"<<
               "StationUpperCase"<<"StationWordWrap"<<"StationTransparency"<<
               "MapShowScrollbar"<<"WindowFullScreen"<<"MapShowTime"<<"MapShowBackground"<<"MapAntialiasing"<<"MapFastScrolling"<<
-              "MapBackColor"<<"MapSimpleTransfers"<<"MapCleanCache"<<"MapLastFile"<<"MapCaching"<<"UiScale";
+              "MapBackColor"<<"MapSimpleTransfers"<<"MapCleanCache"<<"MapLastFile"<<"MapCaching"<<"UiScale"<<"SwipeRoutes";
 
 
  Config.appUiScale=1;
@@ -116,7 +118,7 @@ QMainWindow(parent),map(NULL),SettingsWindow(NULL),ui(new Ui::MainWindow),mUi(NU
  #else
  // MOBILE NONNATIVE INTERFACE
  Config.appUiScale=2.5;
- qApp->setStyle("cleanlooks");
+// qApp->setStyle("cleanlooks");
  MobileVersion=2;
 
  // Orientation - set manually to portrait
@@ -129,7 +131,7 @@ QMainWindow(parent),map(NULL),SettingsWindow(NULL),ui(new Ui::MainWindow),mUi(NU
 // #endif
  #endif
  appPath="/home/user/MyDocs/Data/qMetro/";
- cachePath=appPath+".cache/";
+ cachePath=appPath+"cache/";
  appConfigFile="/home/user/.config/qMetro/config.conf";
 #endif
 #ifdef Q_OS_ANDROID
@@ -189,7 +191,7 @@ QMainWindow(parent),map(NULL),SettingsWindow(NULL),ui(new Ui::MainWindow),mUi(NU
  toggleLang(Config.locale);
 
  ui->setupUi(this); // UI #############################
- loadSkin(ini->value("Skin").toString());
+// loadSkin(ini->value("Skin").toString());
  //ui->labelLoading->setText("<H1>"+ui->labelLoading->text()+"</H1>");
  showPageLoading();
  restoreState(QByteArray::fromHex(ini->value("WindowState").toByteArray()));
@@ -201,8 +203,12 @@ QMainWindow(parent),map(NULL),SettingsWindow(NULL),ui(new Ui::MainWindow),mUi(NU
   removeToolBar(ui->toolBar);
 
   // set UI size for device
-  Config.appIconSize=ICONSIZE=qMin(qApp->desktop()->width(),qApp->desktop()->height()) / 6.5;
-  Config.appFont.setPixelSize(ICONSIZE/2.5);
+  Config.appIconSize=ICONSIZE=qMin(qApp->desktop()->width(),qApp->desktop()->height()) / qreal(6.5);
+#if defined(Q_WS_MAEMO_5)
+  Config.appFont.setPixelSize(ICONSIZE/qreal(2.7));
+#else
+  Config.appFont.setPixelSize(ICONSIZE/qreal(2.5));
+#endif
   Config.appUiScale=1;
  }
  else
@@ -275,8 +281,11 @@ if(LITE)
  map->config.MobileVersion=MobileVersion;
  map->config.locale=Config.locale;
  connect(map,SIGNAL(trackText(QString)),ui->textDescription,SLOT(setText(QString)));
- if(!MobileVersion) // show description panel
-   connect(map,SIGNAL(trackFinded(bool)),ui->mFind,SLOT(setChecked(bool)));
+ if(!MobileVersion)
+ {
+   connect(map,SIGNAL(trackFinded(bool)),ui->mFind,SLOT(setChecked(bool))); // show description panel
+   connect(map,SIGNAL(trackShowIndex(int)),ui->cbRoute,SLOT(setCurrentIndex(int)));
+ }
 
  connect(map,SIGNAL(delayNames(QStringList)),this,SLOT(setDelayNames(QStringList)));
  connect(map,SIGNAL(trackNames(QStringList)),this,SLOT(setTrackNames(QStringList)));
@@ -416,6 +425,7 @@ if(LITE)
  // Remove context menu from all widgets ("Actions")
  QWidgetList widgets=QApplication::allWidgets();
  foreach(QWidget* w,widgets) w->setContextMenuPolicy(Qt::NoContextMenu);
+ widgets.clear();
 #endif
 
 
@@ -433,10 +443,14 @@ if(LITE)
   map->verticalScrollBar()->setValue(Config.mapPosition.y()+yOffset);
  }
 
+ // SWIPE!
+ QGestureRecognizer* pRecognizer = new SwipeGestureRecognizer(qMin(qApp->desktop()->width(),qApp->desktop()->height())/qreal(1.2));
+ m_gestureId = QGestureRecognizer::registerRecognizer(pRecognizer);
 }
 
 MainWindow::~MainWindow()
 {
+ QGestureRecognizer::unregisterRecognizer(m_gestureId);
  delete ui;
 }
 
@@ -508,6 +522,7 @@ bool MainWindow::eventFilter(QObject *obj, QEvent *e)
 #if defined(Q_OS_SYMBIAN) || defined(Q_OS_ANDROID)
    QList<QMenu*> menus=findChildren<QMenu*>();
    foreach(QMenu *m,menus) m->setTitle(m->title().remove("&"));
+   menus.clear();
 #endif
    return 1;
   }
@@ -536,7 +551,7 @@ bool MainWindow::eventFilter(QObject *obj, QEvent *e)
    if(key==Qt::Key_F11) ui->mFullScreen->setChecked(windowState()!=Qt::WindowFullScreen);
    QString char_key=event->text().simplified();
    //android menu:16777301
-   if(!ui->mFind->isChecked() && !char_key.isEmpty() && key!=16777301)//((key>=Qt::Key_A && key<=Qt::Key_Z)||(key>=Qt::Key_0 && key<=Qt::Key_9)) )
+   if(!ui->mFind->isChecked() && event->modifiers()==Qt::NoModifier && !char_key.simplified().isEmpty() && key!=16777301)//((key>=Qt::Key_A && key<=Qt::Key_Z)||(key>=Qt::Key_0 && key<=Qt::Key_9)) )
    {
     ui->mFind->setChecked(1);
     ui->eSearch->setFocus();
@@ -640,24 +655,12 @@ if (fileName.isEmpty()) return;
 
 void MainWindow::loadSkin(QString skinName)
 {
- //qDebug() << skinName;
- if(skinName.isEmpty()) skinName="Default";
-// if(skinName.isEmpty()) skinName=STYLE_APP_DEFAULT;
- if(Config.appSkinName==skinName) return;
-
- QString skinPath=appPath+"skin/";
- QString fullPath=skinPath+skinName+"/";
- QString styleSheet,value,url="url(",rc=":#(",args="/*%1%2%3%4%5%6%7*/";
-
- // load default icons
- if(actionIcons.count())
- {
-  int i=0;
-  QList<QAction*> actions = findChildren<QAction*>();
-  foreach(QAction *a,actions) if(!a->objectName().isEmpty()) a->setIcon(actionIcons.at(i++));
- }
+//qDebug() << 0 << skinName << SKIN_DEFAULT << Config.appSkinName;
+ skinName=skinName.toLower();
+ if(skinName.isEmpty()) skinName="default";
 
  // unpack skins
+ QString skinPath=appPath+"skin/";
  QDir Dir(skinPath);
  if(Dir.exists())
   foreach(QFileInfo info, Dir.entryInfoList(QStringList()<<"*.zip",QDir::NoDotAndDotDot | QDir::Files))
@@ -666,25 +669,37 @@ void MainWindow::loadSkin(QString skinName)
     QFile::remove(info.absoluteFilePath());
   }
 
+ if(Config.appSkinName==skinName) return;
+
+ QString fullPath=skinPath+skinName+"/";
+ QString styleSheet,value,url="url(",rc=":#(",args="/*%1%2%3%4%5%6%7*/";
+//qDebug() << 1;
+ // load default icons
+ if(actionIcons.count())
+ {
+  int i=0;
+  QList<QAction*> actions = findChildren<QAction*>();
+  foreach(QAction *a,actions) if(!a->objectName().isEmpty()) a->setIcon(actionIcons.at(i++));
+  actions.clear();
+//qDebug() << 1.1;
+ }
+
  if(!QFile::exists(fullPath))
  {
   STYLE_MAIN=STYLE_MAIN_DEFAULT+args;
   STYLE_MAP=STYLE_MAP_DEFAULT+args;
-
-  if(!QStyleFactory::keys().contains(skinName,Qt::CaseInsensitive))
-  {
-   if(this->style()->objectName()!=SKIN_DEFAULT) qApp->setStyle(SKIN_DEFAULT);
-   Config.appSkinName=SKIN_DEFAULT;
-  }
-  else
+  if(QStyleFactory::keys().contains(skinName,Qt::CaseInsensitive))
   {
    qApp->setStyle(skinName);
    Config.appSkinName=skinName;
+//   qDebug() << 1.15;
   }
   Config.appFont.fromString(STYLE_FONT_DEFAULT);
   setScaleForUi(Config.appUiScale);
+// qDebug() << 1.2;
   return;
  }
+//qDebug() << 2;
  Config.appSkinName=skinName;
  QFile fileStyle;
  styleSheet="";
@@ -709,7 +724,8 @@ void MainWindow::loadSkin(QString skinName)
  fileStyle.close();
  QSettings ini(fullPath+"main.ini",QSettings::IniFormat);
  ini.beginGroup("Main");
- qApp->setStyle(ini.value("Style",SKIN_DEFAULT).toString());
+ value=ini.value("Style").toString().trimmed();
+ if(!value.isEmpty()) qApp->setStyle(value);
  value=ini.value("Font",STYLE_FONT_DEFAULT).toString().trimmed();
  Config.appFont.fromString(value);
  if(MobileVersion) Config.appFont.setPixelSize(ICONSIZE/2.6);
@@ -736,8 +752,9 @@ void MainWindow::loadSkin(QString skinName)
    foreach(QAction *a,actions)
     if(a->objectName().contains(key,Qt::CaseInsensitive)) { a->setIcon(QIcon(value)); break; }
  }
-
+ actions.clear();
  ini.endGroup();
+//qDebug() << 3;
 }
 
 void MainWindow::on_mOpen_triggered()
@@ -752,7 +769,7 @@ void MainWindow::on_mSave_triggered()
 
 void MainWindow::on_mTest_triggered()
 {
- qDebug() << map->horizontalScrollBar()->value();
+
 }
 
 void MainWindow::on_eSearch_returnPressed()
@@ -941,7 +958,7 @@ void infoAddTab(QWidget *widget, const QString &Caption,const QString &Text)
  // FIX IT: double scroll. need something better then that
  TextEdit->setSizePolicy(QSizePolicy::Expanding,QSizePolicy::Ignored);
 
- if(widget->metaObject()->className()==QString("QTabWidget").toAscii())
+ if(widget->metaObject()->className()==QString("QTabWidget").toLatin1())
  {
   ((QTabWidget*)widget)->addTab(TextEdit,Caption);
   if(!mainWnd->MobileVersion) TextEdit->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
@@ -1197,6 +1214,7 @@ void applySettings(const IniSettingMap &settings)
    case ikMSimpleTransfers: map->config.enableSimpleTransfer=value.toInt(); break;
    case ikMLastFile: map->config.mapLastFile=value; break;
    case ikMCaching: map->config.enableCaching=value.toInt(); break;
+   case ikMSwipeRoutes: map->config.enableSwipeRoutes=value.toInt(); break;
    case ikWUiScale: mainWnd->setScaleForUi((qreal)value.toFloat()); break;
    default: break;
    }
