@@ -1,5 +1,6 @@
 //#include <QDebug>
 #include "maproute.h"
+#include "mapedge.h"
 #include "mapview.h"
 
 TMapRoute::TMapRoute()
@@ -33,9 +34,18 @@ TMapNode* TMapRoute::findNode(const QString &nodeName,const QString &nodePairNam
 
   int id=node.at(i)->ID;
   //qDebug() << nodeName << nodePairName << id;
-  if( (id>0 && map->nodeByID[id-1] &&  map->nodeByID[id-1]->Name==nodePairName) ||
+  if( (id>0 && map->nodeByID[id-1] && map->nodeByID[id-1]->Name==nodePairName) ||
       (id<map->nodeByID.count()-1 && map->nodeByID[id+1] && map->nodeByID[id+1]->Name==nodePairName))
        return node.at(i);
+//  if( (id>0 && map->nodeByID[id-1] &&
+//       map->mapGraph[id][id-1] && !map->mapGraph[id][id-1]->assigned) ||
+//      (id<map->nodeByID.count()-1 &&
+//       map->mapGraph[id][id+1] && map->mapGraph[id][id+1]->assigned ))
+//       return node.at(i);
+
+//  if((id>0 && map->mapGraph[id][id-1] && !map->mapGraph[id][id-1]->assigned) ||
+//      id<map->nodeByID.count()-1 && map->mapGraph[id][id+1] && !map->mapGraph[id][id+1]->assigned)
+//      return node.at(i);
   else found=i;
  }
 
