@@ -39,8 +39,6 @@
 #include "maplayer.h"
 #include "mapelement.h"
 
-
-
 //#if defined(Q_WS_MAEMO_5)
 //#include <QtGui/QX11Info>
 //#include <X11/Xlib.h>
@@ -65,6 +63,7 @@ TMapView::TMapView(QString AppPath, QString CachePath) :
  setAttribute(Qt::WA_OpaquePaintEvent);
  setAttribute(Qt::WA_AcceptTouchEvents);
  viewport()->grabGesture(Qt::PinchGesture);
+ viewport()->grabGesture(Qt::SwipeGesture);
  viewport()->setAttribute(Qt::WA_AcceptTouchEvents);
  //setAttribute(Qt::WA_NoSystemBackground);
  //setAttribute(Qt::WA_PaintOnScreen);
@@ -135,7 +134,7 @@ TMapView::TMapView(QString AppPath, QString CachePath) :
  params.appPath=AppPath;
  params.mapCachePath=CachePath;
  params.appName=qApp->applicationName();
- codePage = QTextCodec::codecForName("windows-1251");
+ codePage = QTextCodec::codecForName("Windows-1251");
  
  TimerPopup.setInterval(1000);
  TimerPopup.setSingleShot(1);
@@ -194,41 +193,38 @@ TMapView::~TMapView()
 
 void TMapView::keyPressEvent(QKeyEvent *event)
 {
+//    qDebug() << event->key();
     switch (event->key())
     {
     case Qt::Key_Equal:
     case Qt::Key_Plus:
     case Qt::Key_ZoomIn:
-    case Qt::Key_F7:
-    case 16777330: // android volUp
-        scaleMap(qreal(1.2));
+    case Qt::Key_VolumeDown:
+//    case Qt::Key_F7: // maemo volUp 16777270 // dont work
+        if(mapTrack.count()>1)
+             showNextTrack();
+        else zoomIn();
         break;
+
     case Qt::Key_Minus:
     case Qt::Key_ZoomOut:
-    case Qt::Key_F8:
-    case 16777328: // android volDown
-        scaleMap(qreal(0.8));
+    case Qt::Key_VolumeUp:
+//    case Qt::Key_F8: // maemo volDown 16777271 // dont work
+        if(mapTrack.count()>1)
+             showPreviousTrack();
+        else zoomOut();
         break;
+
     case Qt::Key_Right:
      if(mapTrack.count()>1)
-     {
-      showNextTrack();
-      break;
-     }else
-     {
-      QGraphicsView::keyPressEvent(event);
-      break;
-     }
+          showNextTrack();
+     else QGraphicsView::keyPressEvent(event);
+     break;
     case Qt::Key_Left:
      if(mapTrack.count()>1)
-     {
-      showPreviousTrack();
-      break;
-     }else
-     {
-      QGraphicsView::keyPressEvent(event);
-      break;
-     }
+          showPreviousTrack();
+     else QGraphicsView::keyPressEvent(event);
+     break;
     case '*':
         (config.MobileVersion ? zoomIn():fitMap());
         break;
@@ -423,7 +419,7 @@ void TMapView::scaleMap(qreal scaleFactor)
  if(!state.mapLoaded) return;
  mapStartDragging();
  params.mapZoomFactor = matrix().scale(scaleFactor, scaleFactor).m11(); //mapRect(QRectF(0, 0, 1, 1)).width();
- if (params.mapZoomFactor < qreal(0.1) || params.mapZoomFactor > qreal(20)) return;
+ if (params.mapZoomFactor < qreal(0.3) || params.mapZoomFactor > qreal(15)) return;
  scale(scaleFactor, scaleFactor);
 }
 
@@ -436,7 +432,7 @@ void TMapView::zoomIn()
 void TMapView::zoomOut()
 {
  setTransformationAnchor(AnchorViewCenter);
- scaleMap(1/qreal(1.2));
+ scaleMap(qreal(0.8));
  setTransformationAnchor(AnchorUnderMouse);
 }
 
@@ -458,10 +454,17 @@ void TMapView::fitMap()
 
 void TMapView::loadMap(QString fileName)
 {
- if(!QFile::exists(fileName) || fileName.right(4).toLower()!=".pmz") return;
-
+ if(fileName.right(4).toLower()!=".pmz") return;
  QString imageFile,fname = fileName.section('/', -1 );
 
+ if(!QFile::exists(fileName))
+ {
+  QString tempFileName=params.appPath+"map/"+fname;
+  if(QFile::exists(tempFileName))
+       fileName=tempFileName;
+  else return;
+ }
+
  // clear
  clearMap();
  //
@@ -479,7 +482,7 @@ void TMapView::loadMap(QString fileName)
  params.mapName=cty.value("Name");
  params.mapCityName=cty.value("CityName");
  params.mapRusName=cty.value("RusName");
- QString Letter=codePage->fromUnicode(params.mapCityName.mid(0,1));
+ QString Letter=params.mapCityName.mid(0,1);//codePage->fromUnicode(params.mapCityName.mid(0,1));
  if(BGN[ Letter[0] ]!="")
   config.enableTranslit=(config.locale!=ru);
 
@@ -489,9 +492,9 @@ void TMapView::loadMap(QString fileName)
  if(config.locale==ru && !params.mapRusName.isEmpty()) CityName=params.mapRusName;
  else
  {
-  Letter=codePage->fromUnicode(CityName.mid(0,1));
+  Letter=CityName.mid(0,1);//codePage->fromUnicode(CityName.mid(0,1));
   if(BGN[Letter[0]]!="") CityName=params.mapName;
-  Letter=codePage->fromUnicode(CityName.mid(0,1));
+  Letter=CityName.mid(0,1);//codePage->fromUnicode(CityName.mid(0,1));
   if(BGN[Letter[0]]!="") convertToTranslit(CityName);
  }
  //(params.countryName.isEmpty() ? "":" - ")+params.countryName+
@@ -597,9 +600,9 @@ void TMapView::exportMap(QString fileName,QString ext)
  painter.setRenderHints(Antialiasing);
  drawBackground(&painter,scene->sceneRect());
  scene->render(&painter,rect,rect);
- QImageWriter imageWriter(fileName,ext.toAscii());
+ QImageWriter imageWriter(fileName,ext.toLatin1());
  imageWriter.write(image);
- //image.save(fileName,ext.toAscii());
+ //image.save(fileName,ext.toLatin1());
 }
 
 bool TMapView::extractFiles(QString zipFile, QString extractFiles, QString extractDir)
@@ -1945,7 +1948,7 @@ void TMapView::findTrack(TMapNode *begin,TMapNode *end, QVector< QVector<qreal>
 // qDebug() << ">>> "+testnames+"\n"<< track.countStation << track.countTransfer << track.countSecond;
 
 // qDebug() << mapTrack.count() << countTransfer;
- if(mapTrack.count()<9 && countTransfer && track.countSecond<mapTrack.at(0).countSecond*1.333) // count of tracks
+ if(mapTrack.count()<9 && countTransfer && track.countSecond<mapTrack.at(0).countSecond*qreal(1.8)) // count of tracks
  {
 
 
@@ -1970,6 +1973,20 @@ void TMapView::findTrack(TMapNode *begin,TMapNode *end, QVector< QVector<qreal>
  }
  else workGraph.clear();
 
+
+
+ // sorting tracks
+ TMapTrack tmp;
+ int i,j,k;
+ for(i=0;i<mapTrack.count();i++)
+ {
+    k=i; tmp=mapTrack.at(i);
+    for(j=i+1;j<mapTrack.count();j++)
+      if (mapTrack.at(j).countSecond < tmp.countSecond) { k=j; tmp=mapTrack.at(j); }
+
+    mapTrack.swap(k,i);
+  }
+
  // finding minimum count transfers and set to second
  int min=1;
  for(int i=1;i<mapTrack.count();i++)
@@ -1983,18 +2000,6 @@ void TMapView::findTrack(TMapNode *begin,TMapNode *end, QVector< QVector<qreal>
   }
  if(mapTrack.count()>1 && mapTrack.at(0).countTransfer!=mapTrack.at(min).countTransfer) mapTrack.swap(1,min);
 
- // sorting tracks after second
- TMapTrack tmp;
- int i,j,k;
- for(i=2;i<mapTrack.count();i++)
- {
-    k=i; tmp=mapTrack.at(i);
-    for(j=i+1;j<mapTrack.count();j++)
-      if (mapTrack.at(j).countSecond < tmp.countSecond) { k=j; tmp=mapTrack.at(j); }
-
-    mapTrack.swap(k,i);
-  }
-
 // qDebug() << "tracks: " << mapTrack.count();
 
  QStringList trackList;
@@ -2051,18 +2056,24 @@ void TMapView::showTrack(int i)
 
 void TMapView::showNextTrack()
 {
- if(!mapTrack.count()) return;
+ if(mapTrack.count()<=1) return;
  int i=trackIndex+1;
- if(i==4 || i==mapTrack.count())  i=0;
- showTrack(i);
+ if((config.MobileVersion && i==4) || i==mapTrack.count())  i=0;
+
+ if(config.MobileVersion)
+      showTrack(i);
+ else emit trackShowIndex(i);
 }
 
 void TMapView::showPreviousTrack()
 {
- if(!mapTrack.count()) return;
+ if(mapTrack.count()<=1) return;
  int i=trackIndex-1;
- if(i==-1)  i=(mapTrack.count()<4 ? mapTrack.count()-1:3);
- showTrack(i);
+ if(i==-1)  i=((config.MobileVersion && mapTrack.count()<4) ? mapTrack.count()-1:3);
+
+ if(config.MobileVersion)
+      showTrack(i);
+ else emit trackShowIndex(i);
 }
 
 void TMapView::clearTrack()
@@ -2194,6 +2205,7 @@ void TMapView::defaultConfig()
  config.enableSimpleNode=0;
  config.enableDrawBackground=1;
  config.enableCaching=config.MobileVersion;
+ config.enableSwipeRoutes=config.MobileVersion;
  config.valueTransparency=60;
  config.enableKineticScroll=0;
  params.mapColorBack=Qt::white;
@@ -2288,14 +2300,14 @@ QString TMapView::convertToTextWithTags(QString text)
  while(index != -1)
  {
   QString StrUrl=url.cap();
-  char lastSymbol=StrUrl.right(1).toAscii().at(0);
+  char lastSymbol=StrUrl.right(1).toLatin1().at(0);
   if(lastSymbol==',' || lastSymbol=='.') StrUrl.chop(1);
   int UrlLength=StrUrl.length();
 
-  QString LinkName=QUrl::fromEncoded(StrUrl.toAscii()).toString();
+  QString LinkName=QUrl::fromEncoded(StrUrl.toLatin1()).toString();
   LinkName.replace("http://www.","",Qt::CaseInsensitive);
   LinkName.replace("http://","",Qt::CaseInsensitive);
-  lastSymbol=LinkName.right(1).toAscii().at(0);
+  lastSymbol=LinkName.right(1).toLatin1().at(0);
   if(lastSymbol=='/') LinkName.chop(1);
 
   TagText.replace(index+offset,UrlLength,QString("<a href=\"%1\">").arg(StrUrl) + QString("%1</a>").arg(LinkName));
@@ -2424,84 +2436,28 @@ void TMapView::saveToFile()
 void TMapView::initTranslit()
 {
  if(BGN.count()) return;
+ QFile translit(":/translit_ru");
+ translit.open(QFile::ReadOnly | QFile::Text);
+ QString text=translit.readAll();
+ QStringList chrs=text.split(',');
+ translit.close();
 
- BGN['']="a";
- BGN['']="b";
- BGN['']="v";
- BGN['']="g";
- BGN['']="d";
- BGN['']="e";
- BGN['']="e";
- BGN['']="zh";
- BGN['']="z";
- BGN['']="i";
- BGN['']="y";
- BGN['']="k";
- BGN['']="l";
- BGN['']="m";
- BGN['']="n";
- BGN['']="o";
- BGN['']="p";
- BGN['']="r";
- BGN['']="s";
- BGN['']="t";
- BGN['']="u";
- BGN['']="f";
- BGN['']="kh";
- BGN['']="ts";
- BGN['']="ch";
- BGN['']="sh";
- BGN['']="shch";
- BGN['']="\"";
- BGN['']="y";
- BGN['']="\'";
- BGN['']="e";
- BGN['']="yu";
- BGN['']="ya";
- BGN['']="A";
- BGN['']="B";
- BGN['']="V";
- BGN['']="G";
- BGN['']="D";
- BGN['']="E";
- BGN['']="E";
- BGN['']="Zh";
- BGN['']="Z";
- BGN['']="I";
- BGN['']="Y";
- BGN['']="K";
- BGN['']="L";
- BGN['']="M";
- BGN['']="N";
- BGN['']="O";
- BGN['']="P";
- BGN['']="R";
- BGN['']="S";
- BGN['']="T";
- BGN['']="U";
- BGN['']="F";
- BGN['']="Kh";
- BGN['']="Ts";
- BGN['']="Ch";
- BGN['']="Sh";
- BGN['']="Shch";
- BGN['']="\"";
- BGN['']="Y";
- BGN['']="'";
- BGN['']="E";
- BGN['']="Yu";
- BGN['']="Ya";
+ for(int i=0;i<chrs.count()-1;i=i+2)
+ {
+     BGN[chrs.at(i)[0]]=chrs.at(i+1);
+     //qDebug() << chrs.at(i)[0] << chrs.at(i+1);
+ }
 }
 
 void TMapView::convertToTranslit(QString &text)
 {
+ if(!BGN.count()) return;
  int max=text.count()-1;
- QString str=codePage->fromUnicode(text);
- //qDebug() << str << text;
+
  for(int i=max;i>=0;i--)
  {
-  QString translit=BGN[ str[i] ];
-  if(translit!="") text.replace(i,1,translit);
+  QString chr=BGN[ text[i] ];
+  if(chr!="") text.replace(i,1,chr);
  }
 }
 
@@ -2543,16 +2499,28 @@ bool TMapView::viewportEvent(QEvent *event)
   return true;
  }
  case QEvent::Gesture:
-  if(QGesture *gesture=((QGestureEvent*)event)->gesture(Qt::PinchGesture))
+  if(QGesture *pinch=((QGestureEvent*)event)->gesture(Qt::PinchGesture))
   {
-   QPinchGesture::ChangeFlags changeFlags = ((QPinchGesture*)gesture)->changeFlags();
+   QPinchGesture::ChangeFlags changeFlags = ((QPinchGesture*)pinch)->changeFlags();
    if(changeFlags & QPinchGesture::ScaleFactorChanged)
    {
-    scaleMap(((QPinchGesture*)gesture)->scaleFactor());
+    scaleMap(((QPinchGesture*)pinch)->scaleFactor());
     nodeClick=NULL;
    }
+   return true;
   }
-  return true;
+  if(config.enableSwipeRoutes)
+  if(QGesture *swipe=((QGestureEvent*)event)->gesture(Qt::SwipeGesture))
+  {
+   if(swipe->state()==Qt::GestureFinished)
+   {
+    if(((QSwipeGesture*)swipe)->verticalDirection()==QSwipeGesture::Up)     showNextTrack();
+    if(((QSwipeGesture*)swipe)->verticalDirection()==QSwipeGesture::Down) showPreviousTrack();
+   }
+//   qDebug() << "swipe test";
+   return true;
+  }
+
  break;
 
  default:
@@ -2560,3 +2528,29 @@ bool TMapView::viewportEvent(QEvent *event)
  }
 }
 
+
+
+//bool TMapView::OnSwipeGesture(QSwipeGesture* pSwipe)
+//{
+//   bool result = false;
+
+//   if (pSwipe->state() == Qt::GestureFinished) {
+//      qDebug("Swipe angle: %f", pSwipe->swipeAngle());
+//      switch (SwipeGestureUtil::GetHorizontalDirection(pSwipe)) {
+//         case QSwipeGesture::Left:
+//            qDebug("Swipe Left detected");
+/////
+//            result = true;
+//            break;
+//         case QSwipeGesture::Right:
+//            qDebug("Swipe Right detected");
+/////
+//            result = true;
+//            break;
+//         default:
+//            break;
+//      }
+//   }
+
+//   return result;
+//}
