@@ -54,7 +54,6 @@ public:
   emit sizeChanged();
  }
 
-
 public slots:
 
  void close() { window->close(); }
@@ -80,9 +79,12 @@ public slots:
  void setFullScreen(const bool &IsFull){ window->ui->mFullScreen->setChecked(IsFull);  emit fullScreenChanged(); }
  void showMenu(const bool &IsHide){ window->menuBar()->setVisible(!IsHide); }
 
+ void scaleMap(qreal scale) { window->scaleMap(scale); }
+
 signals:
  void fullScreenChanged();
  void sizeChanged();
+ //void mapScaled(qreal scaleFactor, QPointF pos);
 
 
 private:
