@@ -36,6 +36,7 @@ Settings::Settings(QWidget *parent) :
    int width=fmWidth.width(chk->text());
    if(width>WindowWidth) WindowWidth=width;
   }
+  checks.clear();
 
   WindowWidth+=5;
   setMinimumWidth(WindowWidth+50);
@@ -106,6 +107,7 @@ Settings::Settings(QWidget *parent) :
    fcharm->activateOn(scroll);
    if(!MobileVersion) scroll->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
   }
+ l.clear();
 #endif
 
  QFontMetrics fm(ui->toolBox->font());
@@ -129,6 +131,7 @@ Settings::Settings(QWidget *parent) :
 
  //foreach(QString style,QStyleFactory::keys())  ui->cbSkin->addItem(QIcon(""),style);
  ui->cbSkin->addItems(QStyleFactory::keys());
+// qDebug() << mainWnd->Config.appSkinName;
  ui->cbSkin->setCurrentIndex(ui->cbSkin->findText(mainWnd->Config.appSkinName,Qt::MatchFixedString));
 
  //installEventFilter(this);
@@ -154,6 +157,7 @@ Settings::Settings(QWidget *parent) :
   connect(ui->checkMFastScrolling,SIGNAL(clicked()),this,SLOT(changeSettings()));
   connect(ui->bMBackColor,SIGNAL(clicked()),this,SLOT(changeSettings()));
   connect(ui->checkMCaching,SIGNAL(clicked()),this,SLOT(changeSettings()));
+  connect(ui->checkMSwipeRoutes,SIGNAL(clicked()),this,SLOT(changeSettings()));
 
   //connect(ui->checkMSimpleTransfers,SIGNAL(clicked()),this,SLOT(changeSettings()));
 
@@ -221,7 +225,10 @@ QFont getFontFromLabel(QLabel *Label)
 {
  QFont Font;
  Font=Label->font();
- Font.setPointSizeF(Label->text().section(",",-1).toFloat());
+ if(Font.pointSizeF()==-1)
+      Font.setPixelSize(Font.pixelSize());
+ else Font.setPointSizeF(Font.pointSizeF());
+ //Font.setPointSizeF(s->text().section(",",-1).toFloat());
  return Font;
 }
 
@@ -262,6 +269,7 @@ void Settings::on_bDefaultConfig_clicked()
  ui->spinUiScale->setValue(100);
  ui->checkWFullScreen->setChecked(mainWnd->MobileVersion);
  ui->checkMCaching->setChecked(mainWnd->MobileVersion);
+ ui->checkMSwipeRoutes->setChecked(mainWnd->MobileVersion);
  ui->cbSkin->setCurrentIndex(ui->cbSkin->findText(SKIN_DEFAULT,Qt::MatchFixedString));
 
  // apply
@@ -305,6 +313,7 @@ IniSettingMap Settings::changeSettings()
  // [Other]
  IniKeyMap OtherKeys;
  OtherKeys.insert(ikMCleanCache,QString::number(ui->checkMCleanCache->isChecked()));
+ OtherKeys.insert(ikMSwipeRoutes,QString::number(ui->checkMSwipeRoutes->isChecked()));
  Setting.insert(igOther,OtherKeys);
 
  applySettings(Setting);
@@ -321,7 +330,8 @@ void Settings::loadSettingsToUi(const IniSettingMap &set)
  QFont font;
  value=set.value(igMapView).value(ikStationFont);
  if(!value.isEmpty()) font.fromString(value);
- else                 font=mainWnd->Config.appFont;
+ else                 font=mainWnd->map->params.nodeFontDefault; //map->font(); //mainWnd->Config.appFont;
+// qDebug() << font;
  setFontToLabel(ui->labelSFont,font);
 
  // [MapView]
@@ -386,7 +396,9 @@ void Settings::loadSettingsToUi(const IniSettingMap &set)
  // [Other]
  value=set.value(igOther).value(ikMCleanCache);
  if(!value.isEmpty()) ui->checkMCleanCache->setChecked(value.toInt());
-
+ value=key.value(ikMSwipeRoutes);
+ if(!value.isEmpty()) ui->checkMSwipeRoutes->setChecked(value.toInt());
+ else ui->checkMSwipeRoutes->setChecked(mainWnd->map->config.enableSwipeRoutes);
  //set.value(igMapView).value().toInt()
 
 }
